#!/usr/bin/perl -w
use strict;

use lib 'lib';
use lib '../../lib';
use lib '../../extlib';

use MT::App;
use MT::Asset;
use MT::Template::Context;
#use Data::Dumper;#DEBUG



### Create MT instance
my $app = MT::App->instance
    or die 'Could not retrieve MT instance.';

### Retrieve parameters
my $q = $app->{query}
    or die 'Could not retrieve query object.';
my $mode            = $q->param( 'mode' ) || 'xml';
if ($mode ne 'xml' && $mode ne 'html') {
    $mode = 'xml';
}
my $class           = $q->param( 'class' ) || '*';
my $blog_ids        = $q->param( 'IncludeBlogs' ) || '';
my $search_val      = $q->param( 'query' ) || '';
my $search_field    = $q->param( 'qtype' ) || 'file_name';
my $page            = $q->param( 'page' ) || 1;
my $limit           = $q->param( 'rp' ) || 10;
my $offset          = ($page - 1) * $limit;
my $sortname        = $q->param( 'sortname' ) || 'created_on';
my $sortorder       = $q->param( 'sortorder' ) || 'desc';
my $template_name   = $q->param( 'Template' ) || 'results_asset';
$sortorder = $sortorder eq 'asc'
    ? 'ascend'
    : 'descend';

### serach result print 
my $filename = undef;
if (my @tmpls = ( $app->config->default('SearchAltTemplate'), $app->config->SearchAltTemplate )) {
    for my $tmpl (@tmpls) {
        next unless defined $tmpl;
        my ($nickname, $file) = split /\s+/, $tmpl;
        if ($nickname eq $template_name) {
            $filename = sprintf '%s/search_templates/%s', $app->mt_dir, $file;
            last;
        }
    }
}
if (!$filename) {
    print "Content-type: text/html\n\n";
    print $app->show_error( "Error no find asset search template. Template name [ $template_name ]" );
    exit;
}

### Load template for searching result
my $tmpl = $app->load_tmpl( $filename );
if (!$tmpl) {
    print "Content-type: text/html\n\n";
    print $app->show_error( "Error no find asset search template. File name [ $filename ]" );
    exit;
}



### make search params
my %sh_params;
$sh_params{'class'} = $class;
if ($blog_ids) {
    my $ids = [ split ',', $blog_ids ];
    $sh_params{'blog_id'} = $ids;
}
if ($search_val) {
    $sh_params{$search_field} = { like => "%$search_val%" };
}

### Make search argument
my %arg_params;
$arg_params{'limit'}        = $limit;
$arg_params{'offset'}       = $offset;
$arg_params{'sort'}         = $sortname;
$arg_params{'direction'}    = $sortorder;

### Loading
my $assets = MT::Asset->load_iter( \%sh_params, \%arg_params );

### set search params
my $count = $limit;
my $total = MT::Asset->count( \%sh_params );
my $max = int(($total / $limit)) || 0;
if (($total % $limit) > 0){
    $max++;
}

### Create a new context object
my $ctx = MT::Template::Context->new;
$ctx->stash( 'stash_key'            , 'asset' );
$ctx->stash( 'results'              , $assets );
$ctx->stash( 'count'                , $count );
$ctx->stash( 'asset_search_string'  , $search_val );
$ctx->stash( 'asset_search_page'    , $page );
$ctx->stash( 'asset_search_total'   , $total );
$ctx->stash( 'asset_search_max_page', $max);

$tmpl->context( $ctx );
my $out = $app->build_page( $tmpl );
if (!$out) {
    print "Content-type: text/html\n\n";
    print $app->show_error( "Error template build_page. Template name [ $template_name ]" );
}

### All done successfully!
print "Content-type: text/$mode\n\n$out";

1;