package MT::Plugin::AssetSearch;
#           Copyright (c) 2008 SKYARC System Co.,Ltd.
#           @see http://www.skyarc.co.jp/
use strict;
use warnings;
use MT;
use MT::Plugin;
#use Data::Dumper;#DEBUG

use vars qw( $PLUGIN_NAME $VERSION );
$PLUGIN_NAME = 'AssetSearch';
$VERSION = '1.01';

### Registration of the MT::Plugin
@MT::Plugin::AssetSearch::ISA = qw( MT::Plugin );
my $plugin = __PACKAGE__->new({
    name    => $PLUGIN_NAME,
    version => $VERSION,
    key     => lc $PLUGIN_NAME,
    id      => lc $PLUGIN_NAME,
    author_name => 'SKYARC System Co.,Ltd.',
    author_link => 'http://www.skyarc.co.jp/',
    doc_link => 'http://www.skyarc.co.jp/engineerblog/entry/assetsearch.html',
    l10n_class =>  $PLUGIN_NAME . '::L10N',
    description => <<HTMLHEREDOC,
MTに登録されたアセットの検索を可能にします。
HTMLHEREDOC
});
MT->add_plugin( $plugin );

sub instance { $plugin; }

### Registry
sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        tags => {
            function => {
                'AssetScriptPath' => \&_asset_search_path,
                'AssetSearchString' => \&_asset_search_string,
                'AssetSearchPage' => \&_asset_search_page,
                'AssetSearchTotal' => \&_asset_search_total,
                'AssetSearchMaxPage' => \&_asset_search_max_page,
            },
            block => {
                'AssetSearchResults' => \&_asset_search_tag,
                'AssetNoSearch' => \&_asset_no_search_tag,
            },
        },
    });
}


########################################################################
### Function tags
########################################################################
sub _asset_search_path { MT->instance->app_path. '/plugins/AssetSearch/AssetSearch.cgi';}
sub _asset_search_string { $_[0]->stash('asset_search_string') || ''; }
sub _asset_search_page { $_[0]->stash('asset_search_page') || ''; }
sub _asset_search_total { $_[0]->stash('asset_search_total') || ''; }
sub _asset_search_max_page { $_[0]->stash('asset_search_max_page') || ''; }

########################################################################
### Block tags
########################################################################
sub _asset_no_search_tag {
    my ($ctx, $args, $cond) = @_;

    my $builder = $ctx->stash('builder');
    my $tokens  = $ctx->stash('tokens');
    my $out = $builder->build ($ctx, $tokens, $cond);

    unless ($ctx->stash('asset_search_total')){
        if (!defined $out){
            return $ctx->error ($builder->errstr);
        }
        return $out;
    }else{
        return '';
    }
}
sub _asset_search_tag {
    my ($ctx, $args, $cond) = @_;

    ## If there are no results, return the empty string, knowing
    ## that the handler for <MTNoSearchResults> will fill in the
    ## no results message.
    my $iter = $ctx->stash('results')
        or return '';
    my $count = $ctx->stash('count')
        or return '';
    my $max = $ctx->stash('maxresults');
    my $stash_key = $ctx->stash('stash_key') || 'asset';
  
    my $output = '';
    my $build = $ctx->stash('builder');
    my $tokens = $ctx->stash('tokens');
    my $footer = 0;
    my ($this_object, $next_object);
    $this_object = $iter->()
        or return '';
    for (my $i = 0; $i < $count; $i++) {
        $ctx->stash( $stash_key, $this_object );

        my $blog;
        if ($this_object->blog_id) {
            $blog = MT::Blog->load({ id => $this_object->blog_id });
        }
        local $ctx->{__stash}{blog} = $blog;

        my $author;
        if ($this_object->created_by) {
            my $author = MT::Author->load({ id => $this_object->created_by });
        }
        local $ctx->{__stash}{author} = $author;

        my $ts = $this_object->created_on;
        local $ctx->{current_timestamp} = $ts;

        defined (my $out = $build->build( $ctx, $tokens,
            { %$cond, }
            )) or return $ctx->error( $build->errstr );
        $output .= $out;

        $next_object = $iter->();
        $this_object = $next_object
            or last;
    }
    $output;
}

########################################################################
### Generic use
########################################################################
sub _save_mt_log {
    my ($msg) = @_;

    my $log = MT::Log->new;
    $log->message( $msg );
    $log->level( 1 );
    my @ts = gmtime time;
    my $ts = sprintf '%04d%02d%02d%02d%02d%02d', $ts[5]+1900, $ts[4]+1, @ts[3,2,1,0];
    $log->modified_on( $ts );
    $log->created_on( $ts );
    $log->save;
}

1;
__END__
